<?php
session_start();
include 'conn.php';

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    header("Location: admin_login.php");
    exit();
}

// Fetch the admin username
$admin_id = $_SESSION['admin_id'];
$stmt = $conn->prepare("SELECT username FROM admin WHERE id = ?");
$stmt->execute([$admin_id]);
$admin = $stmt->fetch(PDO::FETCH_ASSOC);
$admin_username = htmlspecialchars($admin['username']);

// Fetch participants data
$sql = "SELECT p.id, p.regid, p.firstname, p.lastname, p.agecategory, p.email, p.gameevent, p.passport, p.path, p.birth_certificate, p.certificate_path, p.region, p.province, p.gender, p.age, p.status, a.username AS approved_by 
        FROM paticipants p 
        LEFT JOIN admin a ON p.approved_by = a.username";

$stmt = $conn->prepare($sql);
$stmt->execute();
$participants = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Ensure no redeclaration of convertToJpg function
if (!function_exists('convertToJpg')) {
    function convertToJpg($source, $destination) {
        $ext = strtolower(pathinfo($source, PATHINFO_EXTENSION));
        $img = null;

        switch ($ext) {
            case 'png':
                $img = imagecreatefrompng($source);
                break;
            case 'gif':
                $img = imagecreatefromgif($source);
                break;
            default:
                return false;
        }

        if ($img) {
            imagejpeg($img, $destination);
            imagedestroy($img);
            return true;
        }
        return false;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>2024 Sport Participants Report</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/buttons/1.7.1/css/buttons.dataTables.min.css">
    <style>
        .logout-btn { position: absolute; top: 20px; right: 20px; }
        .action-buttons { display: flex; flex-direction: column; }
        .action-buttons .btn { margin-bottom: 10px; }
        .viewDocsBtn img { width: 300px; object-fit: cover; }
        #viewDocsModal img { width: 300px; object-fit: cover; }
        .dataTables_wrapper .dataTables_paginate .paginate_button { padding: 0.5em; }
    </style>
</head>
<body>
    <div class="container mt-5 position-relative">
        <a href="logout3.php" class="btn btn-danger logout-btn">Logout</a>
        <h2>Welcome, <?php echo $admin_username; ?></h2>
        <h2>Participants Approval Dashboard</h2>
        <div class="card">
            <div class="card-body">
                <table id="participantsTable" class="table table-striped table-bordered">
                    <thead>
                        <tr>
                            <th>Reg. Number</th>
                            <th>First Name</th>
                            <th>Last Name</th>
<th>Region</th>
                            <th>Province</th>
<th>Gender</th>
                            <th>Age Category</th>
 <th>Age</th>
                            <th>Game Event</th>
                            <th>View Uploaded Credentials</th>
                            <th>Birth Certificate Status</th>
                            <th>Status</th>
                            <th>Approved By</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($participants as $participant): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($participant['regid']); ?></td>
                                <td><?php echo htmlspecialchars($participant['firstname']); ?></td>
                                <td><?php echo htmlspecialchars($participant['lastname']); ?></td>
 <td><?php echo htmlspecialchars($participant['region']); ?></td>
 <td><?php echo htmlspecialchars($participant['province']); ?></td>
 <td><?php echo htmlspecialchars($participant['gender']); ?></td>
                                <td><?php echo htmlspecialchars($participant['agecategory']); ?></td>
<td><?php echo htmlspecialchars($participant['age']); ?> years</td>
                                <td><?php echo htmlspecialchars($participant['gameevent']); ?></td>
                                <td>
                                    <button class="btn btn-info viewDocsBtn" data-toggle="modal" data-target="#viewDocsModal" 
                                        data-passport="<?php echo htmlspecialchars($participant['path']); ?>" 
                                        data-certificate="<?php echo htmlspecialchars($participant['certificate_path']); ?>">
                                        View
                                    </button>
                                </td>
                                <td><?php echo htmlspecialchars($participant['birth_certificate']) ? 'Birth Certificate is uploaded' : 'No birth certificate uploaded'; ?></td>
                                <td><?php echo htmlspecialchars($participant['status']); ?></td>
                                <td><?php echo htmlspecialchars($participant['approved_by']) ?: 'Not approved'; ?></td>
                                <td class="action-buttons">
                                    <button class="btn btn-success approveBtn" data-id="<?php echo $participant['id']; ?>">Approve</button>
                                    <button class="btn btn-danger rejectBtn" data-id="<?php echo $participant['id']; ?>" data-toggle="modal" data-target="#rejectModal">Reject</button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <div class="card-footer">
                <button onclick="window.print()" class="btn btn-primary">Print</button>
                <a href="export.php" class="btn btn-primary">Export as CSV</a>
            </div>
        </div>
    </div>

    <!-- View Documents Modal -->
    <div class="modal fade" id="viewDocsModal" tabindex="-1" aria-labelledby="viewDocsModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="viewDocsModalLabel">Participant's Passport and Birth Certificate</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <h5>Passport</h5>
                    <img id="passportImg" src="" alt="Passport" class="img-fluid">
                    <h5 class="mt-3">Birth Certificate</h5>
                    <img id="certificateImg" src="" alt="Birth Certificate" class="img-fluid">
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Reject Modal -->
    <div class="modal fade" id="rejectModal" tabindex="-1" aria-labelledby="rejectModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST" action="reject_participant.php">
                    <div class="modal-header">
                        <h5 class="modal-title" id="rejectModalLabel">Reject Participant</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="id" id="rejectId">
                        <div class="form-group">
                            <label for="reason">Reason for Rejection <span class="text-danger">*</span></label>
                            <textarea class="form-control" id="reason" name="reason" rows="3" required></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Reject</button>
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Scripts -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/2.11.6/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/1.7.1/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.2.2/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/1.7.1/js/buttons.html5.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#participantsTable').DataTable({
                dom: 'Bfrtip',
                buttons: [
                    'excelHtml5',
                    'csvHtml5',
                    'pdfHtml5'
                ]
            });

            $('.approveBtn').on('click', function() {
                var id = $(this).data('id');
                $.ajax({
                    url: 'update_status.php',
                    type: 'POST',
                    data: {
                        id: id,
                        status: 'Approved'
                    },
                    success: function(response) {
                        try {
                            var data = JSON.parse(response);
                            if (data.success) {
                                alert('Participant Approved: ' + data.firstname + ' ' + data.lastname);
                                location.reload();
                            } else {
                                alert(data.message);
                            }
                        } catch (e) {
                            console.error('Error parsing response:', e);
                            alert('An error occurred while processing your request.');
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('AJAX Error:', status, error);
                        alert('An error occurred while processing your request.');
                    }
                });
            });

            $('.rejectBtn').on('click', function() {
                var id = $(this).data('id');
                $('#rejectId').val(id);
            });

            $('#viewDocsModal').on('show.bs.modal', function (event) {
                var button = $(event.relatedTarget);
                var passport = button.data('passport');
                var certificate = button.data('certificate');
                var modal = $(this);
                modal.find('#passportImg').attr('src', passport);
                modal.find('#certificateImg').attr('src', certificate);
            });
        });
    </script>
</body>
</html>
