<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>2024 Sport Participants Management and Approval</title>
    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>

<div class="container mt-5">
    <h2 class="text-center">2024 Sport Participants Management and Approval</h2>
    <table class="table table-bordered table-striped">
        <thead>
            <tr>
                <th>Reg ID</th>
                <th>First Name</th>
                <th>Other Names</th>
                <th>Region</th>
                <th>Province</th>
                <th>Date Of Birth</th>
                <th>Age</th>
                <th>Gender</th>
                <th>Game Event</th>
                <th>Age Category</th>
                <th>Passport</th>
                <th>Status</th>
                <th>Reason</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php
            include 'conn.php'; // Include your database connection
            $query = "SELECT * FROM paticipants";
            $stmt = $conn->query($query);
            while($participant = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $passportPath = './passport/' . $participant['passport'];
                $passportExtension = pathinfo($passportPath, PATHINFO_EXTENSION);

                // Initialize flag for image validity
                $isValidImage = true;
                $newPassportPath = '';

                // If the passport file is not a PNG or JPEG, attempt to convert it to PNG
                if (!in_array(strtolower($passportExtension), ['png', 'jpeg', 'jpg'])) {
                    $imageData = @file_get_contents($passportPath);
                    
                    if ($imageData !== false) {
                        $image = @imagecreatefromstring($imageData);
                        if ($image !== false) {
                            $newPassportPath = './passport/' . pathinfo($passportPath, PATHINFO_FILENAME) . '.png';
                            imagepng($image, $newPassportPath);
                            imagedestroy($image);

                            // Update the participant's passport in the database
                            $newPassportName = pathinfo($newPassportPath, PATHINFO_BASENAME);
                            $updateQuery = "UPDATE paticipants SET passport = ? WHERE regid = ?";
                            $updateStmt = $conn->prepare($updateQuery);
                            $updateStmt->execute([$newPassportName, $participant['regid']]);

                            // Set the new passport path for displaying
                            $participant['passport'] = $newPassportName;
                        } else {
                            $isValidImage = false;
                        }
                    } else {
                        $isValidImage = false;
                    }
                }

                // If the image is not valid or cannot be processed, set the path to a placeholder
                if (!$isValidImage || !file_exists($passportPath)) {
                    $participant['passport'] = 'image_not_found.png';
                }
            ?>
            <tr>
                <td><?php echo htmlspecialchars($participant['regid']); ?></td>
                <td><?php echo htmlspecialchars($participant['firstname']); ?></td>
                <td><?php echo htmlspecialchars($participant['lastname']); ?></td>
                <td><?php echo htmlspecialchars($participant['region']); ?></td>
                <td><?php echo htmlspecialchars($participant['province']); ?></td>
                <td><?php echo htmlspecialchars($participant['dob']); ?></td>
                <td><?php echo htmlspecialchars($participant['age']); ?> Years</td>
                <td><?php echo htmlspecialchars($participant['gender']); ?></td>
                <td><?php echo htmlspecialchars($participant['gameevent']); ?></td>
                <td><?php echo htmlspecialchars($participant['agecategory']); ?></td>
                <td>
                    <button class="btn btn-primary" data-toggle="modal" data-target="#passportModal<?php echo htmlspecialchars($participant['regid']); ?>">View Passport</button>
                </td>
                <td><?php echo htmlspecialchars($participant['status']); ?></td>
                <td><?php echo htmlspecialchars($participant['reason']); ?></td>
                <td>
                    <button class="btn btn-success approve-btn" data-id="<?php echo htmlspecialchars($participant['regid']); ?>">Approve</button>
                    <button class="btn btn-danger reject-btn" data-id="<?php echo htmlspecialchars($participant['regid']); ?>">Reject</button>
                </td>
            </tr>

            <!-- Passport Modal -->
            <div class="modal fade" id="passportModal<?php echo htmlspecialchars($participant['regid']); ?>" tabindex="-1" role="dialog" aria-labelledby="passportModalLabel<?php echo htmlspecialchars($participant['regid']); ?>" aria-hidden="true">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="passportModalLabel<?php echo htmlspecialchars($participant['regid']); ?>">Passport</h5>
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                        <div class="modal-body text-center">
                            <?php
                            if ($participant['passport'] == 'image_not_found.png') {
                                echo '<p>Passport Not Found</p>';
                            } else {
                                echo '<img src="./passport/' . htmlspecialchars($participant['passport']) . '" alt="Passport" class="img-fluid">';
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            }
            ?>
        </tbody>
    </table>
</div>

<!-- Approve/Reject Modal -->
<div class="modal fade" id="actionModal" tabindex="-1" role="dialog" aria-labelledby="actionModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="actionModalLabel">Action</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="actionForm">
                    <input type="hidden" id="regid" name="regid">
                    <input type="hidden" id="actionType" name="actionType">
                    <div class="form-group">
                        <label for="reason">Reason (optional for approve)</label>
                        <textarea class="form-control" id="reason" name="reason" rows="3"></textarea>
                    </div>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.0/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
<script>
    $(document).ready(function() {
        $('.approve-btn, .reject-btn').on('click', function() {
            var regid = $(this).data('id');
            var actionType = $(this).hasClass('approve-btn') ? 'approve' : 'reject';
            $('#regid').val(regid);
            $('#actionType').val(actionType);
            $('#reason').val('');
            $('#actionModal').modal('show');
        });

        $('#actionForm').on('submit', function(e) {
            e.preventDefault();
            $.ajax({
                type: 'POST',
                url: 'handle_action.php',
                data: $(this).serialize(),
                success: function(response) {
                    location.reload();
                }
            });
        });
    });
</script>

</body>
</html>
