<?php
session_start();
require_once 'conn2.php'; // Include the database connection file

// Handle login form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate inputs
    $email = trim($_POST['email_address']);
    $password = trim($_POST['password']);

    try {
        // Prepare SQL query to retrieve user data
        $stmt = $conn->prepare("SELECT * FROM report_coordinators WHERE email_address = :email_address");
        $stmt->bindParam(':email_address', $email, PDO::PARAM_STR);
        $stmt->execute();

        // Fetch user data
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($user) { // Only check if the user exists, ignoring password verification
            // User authenticated successfully, set session variables
            $_SESSION['user_id'] = $user['user_id'];
            $_SESSION['zone'] = $user['zone']; 

            // Redirect to the photo card display page
            header("Location: myphotocard.php");
            exit();
        } else {
            $error = "Invalid email. Please try again.";
        }
    } catch (PDOException $e) {
        $error = "Database error: " . $e->getMessage();
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo date('Y'); ?> Sport Photo Card Login</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="icon" type="image/x-icon" href="assets/img/icon2.png" />
    <style>
        /* Background Styling */
        body, html {
            height: 100%;
            margin: 0;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            background: url('./sportadmin/img/stadium.jpg') no-repeat center center/cover;
            position: relative;
        }

        /* Dark Overlay */
        body::before {
            content: "";
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.6);
            z-index: 0;
        }

        /* Centering Container */
        .container {
            position: relative;
            z-index: 1;
            flex: 1;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        /* Glassmorphism Login Card */
        .card-login {
            width: 100%;
            max-width: 400px;
            padding: 30px;
            border-radius: 15px;
            background: rgba(255, 255, 255, 0.15);
            backdrop-filter: blur(10px);
            box-shadow: 0 4px 10px rgba(0,0,0,0.3);
            text-align: center;
            color: #fff;
        }

        /* Form Styling */
        .form-control {
            background: rgba(255, 255, 255, 0.2);
            border: none;
            color: #fff;
        }
        .form-control::placeholder {
            color: rgba(255, 255, 255, 0.7);
        }
        .form-control:focus {
            background: rgba(255, 255, 255, 0.3);
            color: #fff;
            outline: none;
            box-shadow: none;
        }

        /* Login Button */
        .btn-custom {
            background: #28a745;
            border: none;
            padding: 10px;
            font-size: 18px;
            font-weight: bold;
            transition: 0.3s;
        }
        .btn-custom:hover {
            background: #218838;
        }

        /* Footer */
        .footer {
            position: relative;
            width: 100%;
            text-align: center;
            padding: 10px;
            background: rgba(0, 0, 0, 0.7);
            color: #fff;
            font-size: 14px;
        }

    </style>
</head>
<body>
<div class="container">
        <div class="card-login">
            <h2 class="text-uppercase font-weight-bold">Sport Photo Card Login</h2>
            <p class="mb-4">Enter your credentials to access your photo card</p>

            <?php if (isset($error)) : ?>
                <div class="alert alert-danger" role="alert">
                    <?= $error ?>
                </div>
            <?php endif; ?>

            <form method="POST">
                <div class="form-group">
                    <input type="email" class="form-control" id="email" name="email_address" placeholder="Email Address" required>
                </div>
                <div class="form-group">
                    <input type="password" class="form-control" id="password" name="password" placeholder="Password" required>
                </div>
                <button type="submit" class="btn btn-custom btn-block">Login</button>
            </form>

            <!-- New Redirect Button -->
            <div class="text-center mt-4">
                <a href="index.php" class="btn btn-success btn-lg text-white font-weight-bold">
                    <i class="fas fa-user-tie"></i> Go to Main Dashboard
                </a>
            </div>
        </div>
    </div>

    <footer class="footer">
        <span>© <?php echo date('Y'); ?> SPORT PARTICIPANTS PHOTO CARD PORTAL. All rights reserved.</span>
    </footer>

</body>
</html>
