<?php
session_start();
require_once('conn.php');

// Validation functions
function validate_input($data)
{
    return htmlspecialchars(stripslashes(trim($data)));
}

function validate_email($email)
{
    return filter_var($email, FILTER_VALIDATE_EMAIL);
}

function calculate_age($dob)
{
    $date = new DateTime($dob);
    $now = new DateTime();
    $interval = $now->diff($date);
    return $interval->y;
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Sanitize input data
    $regid = validate_input($_POST['regid']);
    $firstname = validate_input($_POST['firstname']);
    $lastname = validate_input($_POST['lastname']);
    $zone = validate_input($_POST['zone']);
    $region = validate_input($_POST['region']);
    $province = validate_input($_POST['province']);
    $dob = validate_input($_POST['dob']);
    $age = calculate_age($dob);  // Automatically calculate age
    $gender = validate_input($_POST['gender']);
    $email = validate_input($_POST['email']);
    $gametype = validate_input($_POST['gametype']);
    $gameevent = validate_input($_POST['gameevent']);
    $agecategory = validate_input($_POST['agecategory']);
    $year = Date('Y');
    // Validate email
    if (!validate_email($email)) {
        $error_message = "Invalid email format!";
    }

    // Passport handling
    if (isset($_FILES["image"]) && $_FILES["image"]["error"] === 0) {
        $file = $_FILES["image"]['name'];
        $file_ext = pathinfo($file, PATHINFO_EXTENSION);
        $allowed_ext = ['jpg', 'jpeg', 'png'];
        if (in_array($file_ext, $allowed_ext) && $_FILES['image']['size'] <= 5242880) {
            $file = str_replace(' ', '', $file);  // Remove spaces in filename
            $file_path = './passport/' . $file;
            move_uploaded_file($_FILES['image']['tmp_name'], $file_path);
        } else {
            $error_message = "Invalid passport file type or size.";
        }
    }

    // Birth certificate handling
    if (isset($_FILES["birth_certificate"]) && $_FILES["birth_certificate"]["error"] === 0) {
        $birth_certificate = $_FILES["birth_certificate"]['name'];
        $birth_certificate_ext = pathinfo($birth_certificate, PATHINFO_EXTENSION);
        $allowed_ext = ["jpeg", "jpg", "png"];
        if (in_array($birth_certificate_ext, $allowed_ext) && $_FILES['birth_certificate']['size'] <= 5242880) {
            $birth_certificate = str_replace(' ', '', $birth_certificate);
            $birth_certificate_path = './certificate/' . $birth_certificate;
            move_uploaded_file($_FILES['birth_certificate']['tmp_name'], $birth_certificate_path);
        } else {
            $error_message = "Invalid certificate file type or size.";
        }
    }

    // Check if participant is already registered
    $sql = "SELECT * FROM paticipants WHERE regid = :regid";
    $stmt = $conn->prepare($sql);
    $stmt->execute(['regid' => $regid]);
    $existing_participant = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($existing_participant) {
        $error_message = "Participant is already registered.";
    } else {
        // Insert new participant
        $insert_query = "INSERT INTO paticipants (regid, firstname, lastname, zone, region, province, dob, age, gender, email, gametype, gameevent, agecategory, passport, path, year, birth_certificate, certificate_path) 
                         VALUES (:regid, :firstname, :lastname, :zone, :region, :province, :dob, :age, :gender, :email, :gametype, :gameevent, :agecategory, :passport, :path, :year, :birth_certificate, :certificate_path)";
        $stmt = $conn->prepare($insert_query);
        $result = $stmt->execute([
            ':regid' => $regid,
            ':firstname' => $firstname,
            ':lastname' => $lastname,
            ':zone' => $zone,
            ':region' => $region,
            ':province' => $province,
            ':dob' => $dob,
            ':age' => $age,
            ':gender' => $gender,
            ':email' => $email,
            ':gametype' => $gametype,
            ':gameevent' => $gameevent,
            ':agecategory' => $agecategory,
            ':passport' => $file,
            ':path' => $file_path,
            ':year' => $year,
            ':birth_certificate' => $birth_certificate,
            ':certificate_path' => $birth_certificate_path
        ]);

        if ($result) {
            $success_message = "Registration successful! Participant's Registration ID is $regid.";
        } else {
            $error_message = "Registration failed. Please try again.";
        }
    }
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo Date("Y"); ?> RCCG DTCE NATIONAL SPORTS FESTIVAL</title>
    <link href="https://fonts.googleapis.com/css?family=Roboto:300,400,500,700" rel="stylesheet">
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.5.0/css/all.css" integrity="sha384-B4dIYHKNBt8Bc12p+WXckhzcICo0wtJAoU8YZTY5qE0Id1GSseTk6S+L3BlXeVIU" crossorigin="anonymous">
    <link rel="icon" type="image/x-icon" href="assets/img/icon2.png" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/css/bootstrap.min.css" integrity="sha384-rbsA2VBKQhggwzxH7pPCaAqO46MgnOM80zW1RWuH61DGLwZJEdK2Kadq2F9CUG65" crossorigin="anonymous">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.2/font/bootstrap-icons.css" integrity="sha384-b6lVK+yci+bfDmaY1u0zE8YYJt0TZxLEAFyYSLHId4xoVvsrQu3INevFKo+Xir8e" crossorigin="anonymous">
    <style>
        /* General styling */
        body {
            font-family: Roboto, Arial, sans-serif;
            background-image: url('assets/img/back.jpg');
            background-size: cover;
            background-repeat: no-repeat;
            background-position: center;
        }

        .container {
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            padding: 20px;
        }

        .form {
            background-color: #fff;
            padding: 20px;
            border-radius: 6px;
            box-shadow: 0 0 20px 0 #095484;
            width: 100%;
            max-width: 800px;
        }

        h1,
        h2 {
            color: #095484;
            font-weight: bold;
            font-size: 1.5rem;
        }

        .banner {
            height: 210px;
            background-image: url("assets/img/Ppl 2.jpg");
            background-size: contain;
            display: flex;
            justify-content: center;
            align-items: center;
            position: relative;
        }

        .banner::after {
            content: "";
            background-color: rgba(0, 0, 0, 0.4);
            position: absolute;
            width: 100%;
            height: 100%;
        }

        input,
        select {
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 3px;
        }

        input {
            width: 100%;
            padding: 8px;
        }

        select {
            width: 100%;
            padding: 8px;
        }

        .item {
            margin: 15px 0;
        }

        .btn-block button {
            background-color: #095484;
            color: white;
            width: 100%;
            padding: 10px;
            border-radius: 5px;
            cursor: pointer;
            font-size: 1.1rem;
        }

        .btn-block button:hover {
            background-color: #0666a3;
        }

        .alert {
            margin-top: 15px;
        }

        /* Responsive adjustments */
        @media (max-width: 768px) {

            .name-item input,
            .city-item select {
                width: 100%;
            }

            .city-item input {
                margin-bottom: 10px;
            }
        }

        /* Countdown timer styles */
        .countdown {
            font-size: 20px;
            font-weight: bold;
            color: #095484;
            margin-top: 20px;
            text-align: center;
        }

        select {
            font-size: 14px;
            padding: 8px;
            background-color: #f0f0f0;
            /* Light gray background */
            color: #333;
            /* Dark text */
        }

        option {
            padding: 8px;
        }

        /* Optional: Style for disabled options */
        option:disabled {
            color: #888;
        }

        /* Centering the countdown on the page */


        .countdown {
            font-family: 'Arial', sans-serif;
            font-weight: bold;
            font-size: 20px;
            color: #fff;
            background: linear-gradient(145deg, #6e7c7d, #374a44);
            border-radius: 15px;
            padding: 20px;
            display: inline-block;
            text-align: center;
            box-shadow: 2px 2px 15px rgba(0, 0, 0, 0.2);
            transform: scale(1);
            transition: transform 0.3s ease-in-out;
        }

        .countdown:hover {
            transform: scale(1.1);
        }

        .countdown span {
            display: inline-block;
            padding: 0 10px;
            margin: 0 5px;
        }

        .countdown span.timer-value {
            font-size: 40px;
            color: #ffdf00;
        }

        .countdown span.timer-label {
            font-size: 16px;
            color: #ffffff;
        }

        .countdown .countdown-end {
            font-size: 24px;
            color: #ff4f4f;
            font-weight: bold;
            margin-top: 10px;
        }

        /* General styling for the container */
        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f9f9f9;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        /* Styling the banner */
        .banner h1 {
            text-align: center;
            font-size: 24px;
            font-weight: bold;
            color: #333;
            margin-bottom: 40px;
        }

        /* Styling the button container */
        .button-container {
            display: flex;
            justify-content: space-between;
            gap: 20px;
            /* Add space between buttons */
            margin-top: 20px;
        }

        /* Style for buttons */
        button.btn {
            display: inline-flex;
            align-items: center;
            padding: 10px 20px;
            font-size: 16px;
            background-color: #007bff;
            color: #fff;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s ease, transform 0.3s ease;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        button.btn i {
            margin-right: 8px;
        }

        button.btn:hover {
            background-color: #0056b3;
            transform: translateY(-2px);
            /* Lift effect on hover */
        }

        button.btn:active {
            transform: translateY(0);
        }

        /* Responsive styling for small screens */
        @media screen and (max-width: 768px) {
            .button-container {
                flex-direction: column;
                /* Stack buttons vertically on smaller screens */
                align-items: center;
            }

            button.btn {
                width: 100%;
                margin-bottom: 10px;
            }
        }

        .alert {
            padding: 15px;
            margin-bottom: 15px;
            border-radius: 5px;
            font-size: 16px;
            text-align: center;
            transition: opacity 0.5s ease-out;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
        }
    </style>
</head>

<body>
    <div class="container">
        <form class="form" method="post" action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']) ?>" enctype="multipart/form-data">
            <div class="banner">
                <h1><?php echo Date("Y"); ?> RCCG DTCE NATIONAL SPORTS FESTIVAL REGISTRATION FORM</h1>
            </div>

            <!-- Logout and Update Record Buttons -->
            <div class="button-container">
                <a href="logout.php">
                    <button type="button" class="btn btn-primary">
                        <i class="fas fa-sign-out-alt"></i> Logout
                    </button>
                </a>
                <a href="participants.php">
                    <button type="button" class="btn btn-primary">
                        <i class="fas fa-pencil"></i> Update Record
                    </button>
                </a>
            </div>


            <div class="countdown" id="countdown"></div>

            <br><br>
            <!-- Display alert based on registration status -->
            <?php if (isset($error_message)): ?>
                <div class="alert alert-danger" id="alert" style="display: block;">
                    <?php echo $error_message; ?>
                </div>
            <?php elseif (isset($success_message)): ?>
                <div class="alert alert-success" id="alert" style="display: block;">
                    <?php echo $success_message; ?>
                </div>
            <?php endif; ?>

            <h2><img src="assets/img/icon2.png" width="40px" alt="logo"> Participant Details</h2>
            <hr>

            <?php


            // Assuming the zone is something like 'Zone 1 - Lagos Regions'
            $zone = $_SESSION['zone'] ?? 'Zone 1 - Lagos Regions';  // Example value, ensure it's set in session

            // Extract the "Zone X" part (e.g., "Zone 1") from the full zone string
            preg_match('/Zone (\d+)/', $zone, $matches);  // This will match "Zone 1" or any "Zone X" format

            if (!empty($matches)) {
                $zone = "Zone " . $matches[1];  // Set zone to the extracted "Zone X" part (e.g., "Zone 1")
            } else {
                $zone = 'Unknown Zone';  // If it couldn't extract the zone number, set a default or handle error
            }

            // Initialize the serial number for registration
            if (!isset($_SESSION['serial'])) {
                $_SESSION['serial'] = 1;  // Start the serial number at 1
            } else {
                $_SESSION['serial']++;  // Increment the serial number for each registration
            }

            // Format the registration ID: "ZONE 1/2025/0001"
            $year = date("Y");  // Current year
            $serial = str_pad($_SESSION['serial'], 4, '0', STR_PAD_LEFT);  // Pad serial number to be 4 digits

            // Create the regid in the desired format
            $regid = $zone . "/" . $year . "/" . $serial;
            ?>

            <div class="item">
                <p>Participant's Registration ID</p>
                <input type="text" name="regid" readonly value="<?php echo htmlspecialchars($regid); ?>" placeholder="Registration ID" />
            </div>

            <div class="item">
                <p>Participant's Full Name</p>
                <div class="name-item">
                    <input type="text" name="firstname" placeholder="First Name" required />
                    <input type="text" name="lastname" placeholder="Last Name" required />
                </div>
            </div>

            <p>Participant's Region & Province</p>
            <div class="city-item">
                <input type="text" name="zone" readonly value="<?php echo $_SESSION['zone'] ?>" placeholder="Zone" required />

                <!-- Region Dropdown -->
                <select name="region" id="region" required>
                    <option disabled selected value="">Select Region</option>
                    <?php
                    // Check if the zone exists in the session
                    if (isset($_SESSION['zone'])) {
                        $zone = $_SESSION['zone'];

                        // Prepare a SQL query to select only distinct regions for the zone and order them numerically
                        $sql = "SELECT DISTINCT region FROM province WHERE zone = :zone ORDER BY CAST(region AS UNSIGNED) ASC";
                        $stmt = $conn->prepare($sql);
                        $stmt->bindParam(':zone', $zone, PDO::PARAM_STR);
                        $stmt->execute();

                        $regions = $stmt->fetchAll(PDO::FETCH_ASSOC);

                        if ($regions) {
                            foreach ($regions as $row) {
                                // Output the region as the number (e.g., region 1 as 1)
                                echo "<option value='" . htmlspecialchars($row['region']) . "'>" . htmlspecialchars($row['region']) . "</option>";
                            }
                        } else {
                            echo "<option disabled>No regions available for this zone.</option>";
                        }
                    } else {
                        echo "<option disabled>Error: Zone not found in session.</option>";
                    }
                    ?>
                </select>

                <!-- Province Dropdown (Initially hidden) -->
                <select name="province" id="province" style="display:none;" required>
                    <option disabled selected value="">Select Province</option>
                </select>
            </div>

            <script>
                // This function is called when the region is changed
                document.getElementById('region').addEventListener('change', function() {
                    var region = this.value; // Get selected region (numeric value or text)
                    var zone = "<?php echo $_SESSION['zone']; ?>"; // Get the current zone from the session

                    // Check if a region is selected
                    if (region) {
                        // Show the province dropdown
                        document.getElementById('province').style.display = 'block';

                        // Send an AJAX request to fetch the provinces for the selected region
                        var xhr = new XMLHttpRequest();
                        xhr.open("GET", "get_provinces.php?zone=" + zone + "&region=" + region, true);
                        xhr.onreadystatechange = function() {
                            if (xhr.readyState == 4 && xhr.status == 200) {
                                var provinces = JSON.parse(xhr.responseText);
                                var provinceSelect = document.getElementById('province');

                                // Clear the current options
                                provinceSelect.innerHTML = '<option disabled selected value="">Select Province</option>';

                                // Populate the province dropdown
                                provinces.forEach(function(province) {
                                    var option = document.createElement('option');
                                    option.value = province.province; // Use the province field from the response
                                    option.textContent = province.province; // Display the province name in the dropdown
                                    provinceSelect.appendChild(option);
                                });
                            }
                        };
                        xhr.send();
                    } else {
                        // If no region is selected, hide the province dropdown
                        document.getElementById('province').style.display = 'none';
                    }
                });
            </script>




            <div class="item">
                <p>Participant's Date of Birth</p>
                <input type="date" name="dob" id="dob" required />
            </div>

            <div class="item">
                <p>Participant's Age</p>
                <input type="text" name="age" id="age" readonly required />
            </div>
            <div class="item">
                <p>Age Category</p>
                <input type="text" name="agecategory" id="agecategory" readonly required />
            </div>
            <p>Participant's Gender & Email</p>
            <div class="city-item">
                <select name="gender" required>
                    <option disabled selected value="">Select Gender</option>
                    <option value="Male">Male</option>
                    <option value="Female">Female</option>
                </select>
                <input type="email" name="email" value="<?php echo $_SESSION['email_address'] ?>" readonly required />
            </div>

            <div class="item">
                <p>Participant's Passport (JPEG or PNG)</p>
                <input type="file" name="image" id="image" required>
            </div>

            <div class="item">
                <p>Participant's Birth Certificate (JPEG or PNG)</p>
                <input type="file" name="birth_certificate" id="birth_certificate" required>
            </div>
            <hr>

            <h2><img src="assets/img/icon2.png" width="40px" alt="logo"> Game Event Registration</h2>

            <div class="item">
                <p>Game Event Type</p>
                <select name="gametype" required>
                    <option disabled selected value="">Select Game Type</option>
                    <option value="Indoor Games">Indoor Games</option>
                    <option value="Outdoor Games (Court Game)">Outdoor Games (Court Game)</option>
                    <option value="Field Event Games">Field Event Games</option>
                    <option value="Athletics">Athletics</option>
                </select>
            </div>

            <p>Game Event & Age Category</p>
            <div class="city-item">
                <select name="gameevent" required>
                    <option disabled selected value="">Select Game Event</option>
                    <?php
                    // Include the database connection file (conn2.php)
                    require 'conn.php'; // Make sure the correct path to conn2.php is used

                    // SQL query to fetch all games
                    $sql = "SELECT * FROM games";

                    // Prepare the SQL statement using PDO
                    $stmt = $conn->prepare($sql);

                    // Execute the query
                    $stmt->execute();

                    // Check if there are any results
                    if ($stmt->rowCount() > 0) {
                        // Fetch results and populate the dropdown
                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            // Echo each game as an option in the dropdown
                            echo "<option>" . htmlspecialchars($row['games']) . "</option>";
                        }
                    } else {
                        // If no games are found
                        echo "<option>No games available</option>";
                    }
                    ?>


                </select>

            </div>


            <style>
                .item label {
                    display: flex;
                    align-items: center;
                    line-height: 1.5;
                }

                .item input[type="checkbox"] {
                    margin-right: 10px;
                    /* Add some space between checkbox and text */
                }
            </style>


            <div class="btn-block">
                <button name="submit">Register</button>
            </div>

            <!-- Countdown Timer -->

            <script>
                var countDownDate = new Date("July 30, 2025 12:00:00").getTime();
                var x = setInterval(function() {
                    var now = new Date().getTime();
                    var distance = countDownDate - now;
                    var days = Math.floor(distance / (1000 * 60 * 60 * 24));
                    var hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
                    var minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
                    var seconds = Math.floor((distance % (1000 * 60)) / 1000);

                    if (distance < 0) {
                        clearInterval(x);
                        document.getElementById("register").disabled = true;
                        document.getElementById("register").innerHTML = "Registration Closed";
                    } else {
                        document.getElementById("countdown").innerHTML = "Registration ends in: " + days + "d " + hours + "h " + minutes + "m " + seconds + "s";
                    }
                }, 1000);
            </script>
            <script>
                document.getElementById('dob').addEventListener('change', function() {
                    var dob = new Date(this.value);
                    var today = new Date();
                    var age = today.getFullYear() - dob.getFullYear();
                    var m = today.getMonth() - dob.getMonth();

                    // Check if birthday hasn't occurred yet this year
                    if (m < 0 || (m === 0 && today.getDate() < dob.getDate())) {
                        age--;
                    }

                    // Display the calculated age
                    document.getElementById('age').value = age;

                    // Calculate the age category based on the age
                    var ageCategory = "";
                    if (age >= 6 && age <= 8) {
                        ageCategory = "Age 6-8 Years";
                    } else if (age >= 9 && age <= 12) {
                        ageCategory = "Age 9-12 Years";
                    } else if (age >= 13 && age <= 15) {
                        ageCategory = "Age 13-15 Years";
                    } else if (age >= 16 && age <= 25) {
                        ageCategory = "Age 16-above Years";
                    }

                    // Set the age category select based on the age
                    document.getElementById('agecategory').value = ageCategory;

                    // Prevent registration for participants whose birthday falls in August and fall into specific age categories
                    var month = dob.getMonth() + 1; // Months are 0-based, so add 1 to make it 1-based.
                    if (month === 8) {
                        if (age >= 6 && age <= 8) {
                            alert("Participants in the age category 6-8 years old cannot register if they have a birthday in August.");
                            document.getElementById('dob').value = ''; // Clear the date of birth
                            document.getElementById('age').value = ''; // Clear the age
                            document.getElementById('agecategory').value = ''; // Clear the age category
                        } else if (age >= 9 && age <= 12) {
                            alert("Participants in the age category 9-12 years old cannot register if they have a birthday in August.");
                            document.getElementById('dob').value = ''; // Clear the date of birth
                            document.getElementById('age').value = ''; // Clear the age
                            document.getElementById('agecategory').value = ''; // Clear the age category
                        } else if (age >= 13 && age <= 15) {
                            alert("Participants in the age category 13-15 years old cannot register if they have a birthday in August.");
                            document.getElementById('dob').value = ''; // Clear the date of birth
                            document.getElementById('age').value = ''; // Clear the age
                            document.getElementById('agecategory').value = ''; // Clear the age category
                        } else if (age >= 16 && age <= 25) {
                            alert("Participants in the age category 16-above years old cannot register if they have a birthday in August.");
                            document.getElementById('dob').value = ''; // Clear the date of birth
                            document.getElementById('age').value = ''; // Clear the age
                            document.getElementById('agecategory').value = ''; // Clear the age category
                        }
                    }
                });
            </script>
            <script>
                // Validate files before submission
                document.querySelector('form').addEventListener('submit', function(event) {
                    var passportFile = document.getElementById('image');
                    var certificateFile = document.getElementById('birth_certificate');

                    // Allowed file extensions
                    var allowedExt = ['jpg', 'jpeg', 'png'];
                    var maxSize = 5242880; // 5MB

                    // Function to check the file extension and size
                    function validateFile(fileInput) {
                        var file = fileInput.files[0];
                        if (file) {
                            // Check file extension
                            var fileExt = file.name.split('.').pop().toLowerCase();
                            if (!allowedExt.includes(fileExt)) {
                                alert("Invalid file type. Please upload a JPEG or PNG file.");
                                return false;
                            }

                            // Check file size
                            if (file.size > maxSize) {
                                alert("File size is too large. Maximum allowed size is 5MB.");
                                return false;
                            }
                        }
                        return true;
                    }

                    // Validate passport file
                    if (!validateFile(passportFile)) {
                        event.preventDefault();
                        return; // Prevent form submission
                    }

                    // Validate birth certificate file
                    if (!validateFile(certificateFile)) {
                        event.preventDefault();
                        return; // Prevent form submission
                    }
                });
            </script>
            <script>
                // JavaScript to automatically hide the alert after 5 seconds
                window.onload = function() {
                    var alert = document.getElementById('alert');
                    if (alert) {
                        setTimeout(function() {
                            alert.style.display = 'none'; // Hide the alert after 5 seconds
                        }, 5000); // 5000ms = 5 seconds
                    }
                };
            </script>
        </form>
    </div>
</body>

</html>