<?php
session_start();
require_once 'conn.php'; // Include the database connection file

// Debug: Check if session variables are set
if (!isset($_SESSION['user_id'])) {
    // Debug: Log a message to help identify the issue
    error_log('Session user_id is not set. Redirecting to coord.php');
    header("Location: coord.php");
    exit();
}

// Check if the region is set in the session
if (!isset($_SESSION['zone'])) {
    // Handle case where the region is not set in the session
    header("Location: coord.php");
    exit();
}

// Get the region from the session
$zone = $_SESSION['zone'];

// Construct the normalized region format expected in the database
// $normalizedRegion = "REGION " . $region;

// Query to fetch all approved participants for the logged-in user's region
$stmt = $conn->prepare("SELECT * FROM paticipants WHERE status = 'Approved' AND zone = :zone");
$stmt->bindParam(':zone', $zone, PDO::PARAM_STR); // Use normalized region
$stmt->execute();
$participants = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Function to generate a unique filename for each participant card
function generateFilename($participant)
{
    return $participant['firstname'] . '_' . $participant['lastname'] . '_card';
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" type="image/x-icon" href="assets/img/icon2.png" />
    <title>Approved Participants</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            padding-top: 70px;
            /* Adjust for navbar */
        }

        .card {
            border: 1px solid #ddd;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            margin-bottom: 40px;
            width: 100%;
            max-width: 400px;
            /* Increase the card size */
        }

        .card-body {
            padding: 1.5rem;
        }

        .card-title {
            font-weight: 700;
            font-size: 1.4rem;
            /* Increase font size */
        }

        .card-text {
            margin-bottom: 0.5rem;
        }

        .card-footer {
            padding-top: 0.5rem;
        }

        .btn-container {
            text-align: center;
        }

        .card-img-top {
            width: 150px;
            /* Increase image size */


        }
    </style>
</head>

<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-dark fixed-top">
        <div class="container">
            <a class="navbar-brand" href="#">SPORT PARTICIPANTS PHOTO CARD PORTAL</a>
            <ul class="navbar-nav ml-auto">
                <li class="nav-item">
                    <a class="nav-link" href="./logout2.php">Logout</a>
                </li>
            </ul>
        </div>
    </nav>
    <div class="container">
        <h2 class="mt-4 mb-4 text-center text-uppercase font-weight-bold">Approved Participants</h2>

        <!-- Display participant cards -->
        <div class="row">
            <?php foreach ($participants as $participant) : ?>
                <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
                    <div class="card shadow-lg border-dark">
                        <div class="card-body text-center">
                            <div>
                                <center><img src="assets/rccg.png" class="img-fluid" alt="RCCG Logo" width="80"></center>
                                <!-- <img src="assets/HEAVEN.png" class="img-fluid" alt="HEAVEN Logo" width="50"> -->
                            </div>

                            <h5 class="card-title text-uppercase font-weight-bold" style="color: #006400;">
    The Redeemed Christian Church of God
</h5>

                            <h6 class="card-subtitle text-uppercase font-weight-bold" style="color: #00008B;">
                                Directorate of Teens & Children Education
                            </h6>

                            <h6 class="card-subtitle text-uppercase text-muted mb-3"><?php echo Date('Y') ?> National Sport Competition</h6>

                            <img src="<?= htmlspecialchars('./passport/' . $participant['passport']) ?>"
                                class="rounded-circle border border-dark mb-3"
                                alt="Passport"
                                style="width: 120px; height: 120px; object-fit: cover;">

                            <h5 class="text-uppercase font-weight-bold"><?= htmlspecialchars($participant['firstname'] . ' ' . $participant['lastname']) ?></h5>

                            <table class="table table-bordered text-left">
                                <tr>
                                    <td><strong>Participant No:</strong></td>
                                    <td><?= htmlspecialchars($participant['regid']) ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Category:</strong></td>
                                    <td class="text-uppercase"><?= htmlspecialchars($participant['agecategory']) ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Age:</strong></td>
                                    <td><?= htmlspecialchars($participant['age']) ?> Years</td>
                                </tr>
                                <tr>
                                    <td><strong>Game Event:</strong></td>
                                    <td><?= htmlspecialchars($participant['gameevent']) ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Region:</strong></td>
                                    <td><?= htmlspecialchars($participant['region']) ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Province:</strong></td>
                                    <td><?= htmlspecialchars($participant['province']) ?></td>
                                </tr>
                            </table>

                            <p class="text-danger font-weight-bold mt-3">SIGNED BY:</p>
                            <h6 class="text-uppercase font-weight-bold">DTCE Sport Director</h6>
                        </div>

                        <div class="card-footer text-center">
                            <button class="btn btn-dark btn-block"
                                onclick="downloadCard(this, '<?= generateFilename($participant) ?>')">
                                Download Card
                            </button>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <!-- Footer -->
    <footer class="footer">
        <div class="container">
            <span class="text-muted">© 2024 SPORT PARTICIPANTS PHOTO CARD PORTAL. All rights reserved.</span>
        </div>
    </footer>

    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <!-- Include html2canvas -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/html2canvas/1.4.1/html2canvas.min.js"></script>

    <script>
        function downloadCard(button, filename) {
            const card = button.closest('.card'); // Get the card container
            const footer = button.closest('.card-footer'); // Get the footer (where the button is)

            footer.style.display = 'none'; // Hide the button before capture

            html2canvas(card, {
                scale: 2
            }).then(canvas => {
                const link = document.createElement('a');
                link.download = filename + '.png';
                link.href = canvas.toDataURL('image/png');
                link.click();
            }).catch(err => {
                alert("Failed to generate the download. Please try again.");
                console.error('Error generating the canvas:', err);
            }).finally(() => {
                footer.style.display = 'block'; // Show the button again after capture
            });
        }
    </script>

</body>

</html>