<?php
session_start(); // Start the session

// Check if the user is logged in and has a region
if (!isset($_SESSION['zone'])) {
    // Redirect to login or show an error message if no region is set
    header("Location: index.php");
    exit();
}

include 'conn.php'; // Include your database connection

$zone =  $_SESSION['zone']; // Get the region from the session

// Fetch participants data for the specific region
$sql = "SELECT id, regid, firstname, lastname, agecategory, email, gameevent, passport, status, reason, birth_certificate FROM paticipants WHERE zone = ?";
$stmt = $conn->prepare($sql);
$stmt->execute([$zone]);
$participants = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Participants Details</title>
    <!-- Latest Bootstrap 5 -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css" rel="stylesheet">
    <link rel="icon" href="assets/img/icon2.png" />
    <style>
        .logout-btn {
            position: absolute;
            top: 20px;
            right: 20px;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <div class="d-flex justify-content-between mb-4">
        <!-- Go Back Button -->
        <a href="form.php" class="btn btn-success">Go Back</a>
         <!-- Logout Button -->
        <a href="logout.php" class="btn btn-danger">Logout</a>
       
    </div>
    
    <h2 class="mb-4"><?php echo strtoupper($_SESSION['zone']); ?> REGISTERED PARTICIPANTS</h2>


    <div class="card">
    <div class="card-body">
        <!-- Wrap the table with the .table-responsive class -->
        <div class="table-responsive">
            <table id="participantsTable" class="table table-bordered">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>RegId</th>
                        <th>First Name</th>
                        <th>Last Name</th>
                        <th>Age Category</th>
                        <th>Game Event</th>
                        <th>Passport Status</th>
                        <th>Birth Certificate Status</th>
                        <th>Status</th>
                        <th>Reason</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($participants as $participant): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($participant['id']); ?></td>
                            <td><?php echo htmlspecialchars($participant['regid']); ?></td>
                            <td><?php echo htmlspecialchars($participant['firstname']); ?></td>
                            <td><?php echo htmlspecialchars($participant['lastname']); ?></td>
                            <td><?php echo htmlspecialchars($participant['agecategory']); ?></td>
                            <td><?php echo htmlspecialchars($participant['gameevent']); ?></td>
                            <td><?php echo !empty($participant['passport']) ? 'Passport is uploaded' : 'No passport uploaded'; ?></td>
                            <td><?php echo !empty($participant['birth_certificate']) ? 'Birth Certificate is uploaded' : 'No birth certificate uploaded'; ?></td>
                            <td><?php echo htmlspecialchars($participant['status']); ?></td>
                            <td><?php echo htmlspecialchars($participant['reason']); ?></td>
                            <td>
                                <button class="btn btn-primary editBtn" data-bs-toggle="modal" data-bs-target="#editModal" data-id="<?php echo $participant['id']; ?>">Upload Credentials</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    <div class="card-footer d-flex justify-content-between">
        <button onclick="window.print()" class="btn btn-primary">Print</button>
        <a href="export.php" class="btn btn-primary">Export as CSV</a>
    </div>
</div>


    <!-- Edit Modal -->
    <div class="modal fade" id="editModal" tabindex="-1" aria-labelledby="editModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST" action="update_participant.php" enctype="multipart/form-data">
                    <div class="modal-header">
                        <h5 class="modal-title" id="editModalLabel">Upload Participant's Credentials</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="id" id="editId">
                        <div class="mb-3">
                            <label for="editPassport" class="form-label">Upload Passport <span class="text-danger">*</span></label>
                            <input type="file" class="form-control" id="editPassport" name="passport" accept="image/*" required>
                        </div>
                        <div class="mb-3">
                            <label for="editBirthCertificate" class="form-label">Upload Birth Certificate <span class="text-danger">*</span></label>
                            <input type="file" class="form-control" id="editBirthCertificate" name="birth_certificate" accept="image/*" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- JS for Bootstrap 5 and DataTables -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap5.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function () {
            var table = $('#participantsTable').DataTable();

            // Handle the Edit button click using event delegation
            $('#participantsTable').on('click', '.editBtn', function() {
                var id = $(this).data('id');
                $('#editId').val(id);
                // Load additional participant data if necessary
                // For example:
                // $.ajax({ url: 'fetch_participant.php', method: 'POST', data: { id: id }, success: function(data) { /* Populate modal fields */ } });
            });
        });
    </script>
</body>
</html>
