<?php
session_start();
include 'conn.php';

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    echo json_encode(['success' => false, 'message' => 'Unauthorized access']);
    exit();
}

// Check if the ID and reason are set
if (isset($_POST['id']) && isset($_POST['reason'])) {
    $id = $_POST['id'];
    $reason = $_POST['reason'];

    // Validate the inputs
    if (empty($id) || empty($reason)) {
        echo json_encode(['success' => false, 'message' => 'ID or reason not provided']);
        exit();
    }

    // Update the participant status and reason in the database
    try {
        $conn->beginTransaction();

        // Update the status and reason
        $sql = "UPDATE paticipants SET status = 'Pending', reason = :reason WHERE id = :id";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(':reason', $reason);
        $stmt->bindParam(':id', $id);
        $stmt->execute();

        // Fetch participant details
        $sql = "SELECT firstname, lastname FROM paticipants WHERE id = :id";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $participant = $stmt->fetch(PDO::FETCH_ASSOC);

        $conn->commit();

        if ($stmt->rowCount() > 0) {
            echo json_encode([
                'success' => true,
                'message' => 'Participant rejected successfully',
                'firstname' => $participant['firstname'],
                'lastname' => $participant['lastname']
            ]);
        } else {
            echo json_encode(['success' => false, 'message' => 'No changes made']);
        }
    } catch (PDOException $e) {
        $conn->rollBack();
        echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
    }
} else {
    echo json_encode(['success' => false, 'message' => 'ID or reason not provided']);
}
?>
