<?php 
session_start();

include('../../conn.php');

// Check if user is logged in
if (!isset($_SESSION['username'])) {
    header('Location: ../../login.php');
    exit();
}

// Function to check file type (JPEG/JPG)
function is_valid_file_type($file_path) {
    $valid_extensions = ['jpeg', 'jpg'];
    $file_ext = strtolower(pathinfo($file_path, PATHINFO_EXTENSION));
    return in_array($file_ext, $valid_extensions);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Manual approval logic
    if (isset($_POST['regid']) && isset($_POST['reason'])) {
        $regid = $_POST['regid'];
        $reason = $_POST['reason'];

        // Check if the passport and birth certificate are in valid format
        $stmt = $conn->prepare("SELECT passport, birth_certificate FROM paticipants WHERE regid = :regid");
        $stmt->bindParam(':regid', $regid);
        $stmt->execute();
        $participant = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($participant) {
            $passport_valid = is_valid_file_type($participant['passport']);
            $birth_certificate_valid = is_valid_file_type($participant['birth_certificate']);

            // Proceed only if both files are valid
            if ($passport_valid && $birth_certificate_valid) {
                $update_stmt = $conn->prepare("UPDATE paticipants SET status = 'Approved', reason = :reason WHERE regid = :regid");
                $update_stmt->bindParam(':regid', $regid);
                $update_stmt->bindParam(':reason', $reason);
                $update_stmt->execute();
                echo "<script>
                        alert('Participant approved successfully');
                        window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php after approval
                      </script>";
            } else {
                $reason = 'Error: Passport or Birth Certificate is not in the correct format (JPEG/JPG).';
                // Update the reason in the database if the files are not valid
                $update_stmt = $conn->prepare("UPDATE paticipants SET reason = :reason WHERE regid = :regid");
                $update_stmt->bindParam(':regid', $regid);
                $update_stmt->bindParam(':reason', $reason);
                $update_stmt->execute();
                echo "<script>
                        alert('Error: Passport or Birth Certificate is not in the correct format (JPEG/JPG).');
                        window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php after error
                      </script>";
            }
        } else {
            echo "<script>
                    alert('Participant not found.');
                    window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php if participant not found
                  </script>";
        }
    }

    // CSV upload logic
    if (isset($_FILES['csv_file'])) {
        $csv_file = $_FILES['csv_file']['tmp_name'];

        if (is_uploaded_file($csv_file)) {
            // Open the CSV file for reading
            if (($handle = fopen($csv_file, 'r')) !== false) {
                // Skip the header row
                fgetcsv($handle);

                // Prepare the statement to update status and reason
                $update_stmt = $conn->prepare("UPDATE paticipants SET status = 'Approved', reason = 'Completed and Approved registration' WHERE regid = :regid");
                $update_reason_stmt = $conn->prepare("UPDATE paticipants SET reason = :reason WHERE regid = :regid");

                // Loop through each row in the CSV
                while (($data = fgetcsv($handle)) !== false) {
                    $regid = $data[0];  // Assuming the first column contains the regid

                    // Fetch the passport and birth certificate for validation
                    $stmt = $conn->prepare("SELECT passport, birth_certificate FROM paticipants WHERE regid = :regid");
                    $stmt->bindParam(':regid', $regid);
                    $stmt->execute();
                    $participant = $stmt->fetch(PDO::FETCH_ASSOC);

                    if ($participant) {
                        $passport_valid = is_valid_file_type($participant['passport']);
                        $birth_certificate_valid = is_valid_file_type($participant['birth_certificate']);

                        // Proceed only if both files are valid
                        if ($passport_valid && $birth_certificate_valid) {
                            // Update the participant's status and reason if files are valid
                            $update_stmt->bindParam(':regid', $regid);
                            $update_stmt->execute();
                        } else {
                            // Update the reason if files are not valid
                            $reason = 'Error: Passport or Birth Certificate is not in the correct format (JPEG/JPG).';
                            $update_reason_stmt->bindParam(':regid', $regid);
                            $update_reason_stmt->bindParam(':reason', $reason);
                            $update_reason_stmt->execute();
                        }
                    }
                }

                fclose($handle);
                echo "<script>
                        alert('Participants approval process completed via CSV.');
                        window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php after CSV process is done
                      </script>";
            } else {
                echo "<script>
                        alert('Error opening the CSV file');
                        window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php after error
                      </script>";
            }
        } else {
            echo "<script>
                    alert('No file uploaded or error with the upload');
                    window.location.href = 'list_competitions.php'; // Redirect to list_competitions.php if file is not uploaded or error occurred
                  </script>";
        }
    }
}
?>
